@@ -2,7 +2,7 @@
  * @file gnome-cmd-manage-bookmarks-dialog.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2018 Uwe Scholz\n
+ * @copyright (C) 2013-2019 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -369,7 +369,7 @@ static void remove_clicked_callback (GtkButton *button, GtkWidget *bm_view)
             
             main_win->update_bookmarks ();
             
-            gnome_cmd_data.save_xml ();
+            gnome_cmd_data.save_bookmarks ();
         }
     }
 }
@@ -563,7 +563,7 @@ void gnome_cmd_bookmark_add_current (GnomeCmdDir *dir)
 
         main_win->update_bookmarks();
         
-        gnome_cmd_data.save_xml ();
+        gnome_cmd_data.save_bookmarks ();
     }
     else
     {
