@@ -34,7 +34,6 @@
 #include "gnome-cmd-types.h"
 #include "gnome-cmd-file-list.h"
 #include "gnome-cmd-regex.h"
-#include "gnome-cmd-xml-config.h"
 #include "filter.h"
 #include "history.h"
 #include "dict.h"
@@ -128,6 +127,7 @@ GcmdSettings *gcmd_settings_new (void);
 #define GCMD_SETTINGS_DIRECTORY_HISTORY               "directory-history"
 #define GCMD_SETTINGS_SEARCH_WIN_WIDTH                "search-win-width"
 #define GCMD_SETTINGS_SEARCH_WIN_HEIGHT               "search-win-height"
+#define GCMD_SETTINGS_SEARCH_WIN_IS_TRANSIENT         "search-win-is-transient"
 #define GCMD_SETTINGS_SEARCH_PATTERN_HISTORY          "search-pattern-history"
 #define GCMD_SETTINGS_SEARCH_TEXT_HISTORY             "search-text-history"
 #define GCMD_SETTINGS_SEARCH_PROFILES                 "search-profiles"
@@ -317,6 +317,7 @@ struct GnomeCmdData
         gboolean                     save_dir_history_on_exit;
         gboolean                     save_cmdline_history_on_exit;
         gboolean                     save_search_history_on_exit;
+        gboolean                     search_window_is_transient {true};
         gchar                       *symlink_prefix;
         gint                         main_win_pos[2];
         // Format
@@ -361,7 +362,7 @@ struct GnomeCmdData
         gboolean                     device_only_icon;
         gboolean                     skip_mounting;
 
-        Options(): gcmd_settings(NULL),
+        Options(): gcmd_settings(nullptr),
                    left_mouse_button_mode(LEFT_BUTTON_OPENS_WITH_DOUBLE_CLICK),
                    left_mouse_button_unselects(TRUE),
                    middle_mouse_button_mode(MIDDLE_BUTTON_GOES_UP_DIR),
@@ -377,11 +378,11 @@ struct GnomeCmdData
                    save_dir_history_on_exit(TRUE),
                    save_cmdline_history_on_exit(TRUE),
                    save_search_history_on_exit(TRUE),
-                   symlink_prefix(NULL),
+                   symlink_prefix(nullptr),
                    size_disp_mode(GNOME_CMD_SIZE_DISP_MODE_POWERED),
                    perm_disp_mode(GNOME_CMD_PERM_DISP_MODE_TEXT),
-                   date_format(NULL),
-                   list_font(NULL),
+                   date_format(nullptr),
+                   list_font(nullptr),
                    list_row_height(16),
                    ext_disp_mode(GNOME_CMD_EXT_DISP_BOTH),
                    layout(GNOME_CMD_LAYOUT_MIME_ICONS),
@@ -389,7 +390,7 @@ struct GnomeCmdData
                    use_ls_colors(FALSE),
                    icon_size(16),
                    icon_scale_quality(GDK_INTERP_HYPER),
-                   theme_icon_dir(NULL),
+                   theme_icon_dir(nullptr),
                    always_show_tabs(FALSE),
                    tab_lock_indicator(TAB_LOCK_ICON),
                    confirm_delete(TRUE),
@@ -397,17 +398,17 @@ struct GnomeCmdData
                    confirm_copy_overwrite(GNOME_CMD_CONFIRM_OVERWRITE_QUERY),
                    confirm_move_overwrite(GNOME_CMD_CONFIRM_OVERWRITE_QUERY),
                    confirm_mouse_dnd(TRUE),
-                   backup_pattern(NULL),
-                   backup_pattern_list(NULL),
+                   backup_pattern(nullptr),
+                   backup_pattern_list(nullptr),
                    honor_expect_uris(FALSE),
-                   viewer(NULL),
+                   viewer(nullptr),
                    use_internal_viewer(TRUE),
-                   editor(NULL),
-                   differ(NULL),
-                   sendto(NULL),
-                   termopen(NULL),
-                   termexec(NULL),
-                   fav_apps(NULL),
+                   editor(nullptr),
+                   differ(nullptr),
+                   sendto(nullptr),
+                   termopen(nullptr),
+                   termexec(nullptr),
+                   fav_apps(nullptr),
                    device_only_icon(FALSE),
                    skip_mounting(FALSE)
         {
@@ -510,13 +511,13 @@ struct GnomeCmdData
 
         void add_fav_app(GnomeCmdApp *app)
         {
-            g_return_if_fail (app != NULL);
+            g_return_if_fail (app != nullptr);
             fav_apps = g_list_append (fav_apps, app);
         }
 
         void remove_fav_app(GnomeCmdApp *app)
         {
-            g_return_if_fail (app != NULL);
+            g_return_if_fail (app != nullptr);
             fav_apps = g_list_remove (fav_apps, app);
         }
 
@@ -625,7 +626,7 @@ struct GnomeCmdData
 
     struct Private;
 
-    Private *priv;
+    Private *priv {nullptr};
 
   private:
 
@@ -636,7 +637,6 @@ struct GnomeCmdData
     void load_directory_history();
     void load_intviewer_defaults();
     gboolean save_auto_load_plugins();
-    void load_bookmarks();
     void load_keybindings();
     void save_keybindings();
     void load_connections();
@@ -645,13 +645,12 @@ struct GnomeCmdData
     void save_directory_history();
     void save_search_history();
     void save_intviewer_defaults();
-    void save_devices_via_gsettings();
-    void save_fav_apps_via_gsettings();
+    void save_devices();
+    void save_fav_apps();
     void add_advrename_profile_to_gvariant_builder(GVariantBuilder *builder, AdvrenameConfig::Profile profile);
     gboolean add_bookmark_to_gvariant_builder(GVariantBuilder *builder, std::string bookmarkName, GnomeCmdCon *con);
     void add_search_profile_to_gvariant_builder(GVariantBuilder *builder, SearchProfile searchProfile);
     inline gint get_int (const gchar *path, int def);
-    inline gchar* get_string (const gchar *path, const gchar *def);
     inline void set_string (const gchar *path, const gchar *value);
     inline gboolean get_bool (const gchar *path, gboolean def);
     inline void set_color (const gchar *path, GdkColor *color);
@@ -659,7 +658,7 @@ struct GnomeCmdData
   public:
 
     Options                      options;
-    GcmdSettings                 *settings;
+    GcmdSettings                 *settings {nullptr};
 
     std::vector<SearchProfile>   profiles;
 
@@ -670,14 +669,14 @@ struct GnomeCmdData
 
     gboolean                     horizontal_orientation;
 
-    gboolean                     show_toolbar;
-    gboolean                     show_devbuttons;
-    gboolean                     show_devlist;
-    gboolean                     cmdline_visibility;
-    gboolean                     buttonbar_visibility;
-    gboolean                     mainmenu_visibility;
+    gboolean                     show_toolbar {TRUE};
+    gboolean                     show_devbuttons {TRUE};
+    gboolean                     show_devlist {TRUE};
+    gboolean                     cmdline_visibility {TRUE};
+    gboolean                     buttonbar_visibility {TRUE};
+    gboolean                     mainmenu_visibility {TRUE};
 
-    guint                        dev_icon_size;
+    guint                        dev_icon_size {16};
     guint                        fs_col_width[GnomeCmdFileList::NUM_COLUMNS];
     guint                        gui_update_rate;
 
@@ -706,27 +705,20 @@ struct GnomeCmdData
     void load_colors();
     void load_color_themes();
     void load_tabs_from_gsettings();
-    void load_devices_from_gsettings();
-    void load_fav_apps_from_gsettings();
+    void load_devices();
+    void load_fav_apps();
     void gsettings_init();
     void migrate_all_data_to_gsettings();
-    gint migrate_data_int_value_into_gsettings(gint user_value, GSettings *settings, const char *key);
-    gboolean migrate_data_string_value_into_gsettings(const char* user_value, GSettings *settings, const char *key);
     void load_more();
-    inline GList* load_string_history (const gchar *format, gint size);
     void load_advrename_profiles ();
     void save_advrename_profiles ();
     void load_search_profiles ();
     void save_search_profiles ();
     void save_bookmarks();
+    void load_bookmarks();
     void save();
-    gint gnome_cmd_data_get_int (const gchar *path, int def);
-    gchar* gnome_cmd_data_get_string (const gchar *path, const gchar *def);
-    void gnome_cmd_data_set_string (const gchar *path, const gchar *value);
     gboolean gnome_cmd_data_parse_color (const gchar *spec, GdkColor *color);
     gboolean set_color_if_valid_key_value(GdkColor *color, GSettings *settings, const char *key);
-    void gnome_cmd_data_get_color_gnome_config (const gchar *path, GdkColor *color);
-    gboolean gnome_cmd_data_get_bool (const gchar *path, gboolean def);
     gboolean set_gsettings_when_changed (GSettings *settings, const char *key, gpointer value);
     gboolean set_gsettings_color_when_changed (GSettings *settings, const char *key, GdkColor *color);
     gboolean set_gsettings_enum_when_changed (GSettings *settings, const char *key, gint value);
@@ -734,9 +726,6 @@ struct GnomeCmdData
     gboolean set_valid_color_string(GSettings *settings, const char* key);
 
     GnomeCmdConRemote *get_quick_connect() const       {  return quick_connect;                     }
-
-    GnomeCmdFileList::ColumnID get_sort_col(FileSelectorID id) const;
-    GtkSortType get_sort_direction(FileSelectorID id) const;
 };
 
 gpointer gnome_cmd_data_get_con_list ();
